/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: UserDataHandler.java 511423 2007-02-25 03:21:05Z vgritsenko $
 */

package org.w3c.dom;

/**
 * When associating an object to a key on a node using Node.setUserData()
 * the application can provide a handler that gets called when the node the
 * object is associated to is being cloned, imported, or renamed. This can be
 * used by the application to implement various behaviors regarding the data
 * it associates to the DOM nodes. This interface defines that handler.
 *
 * @since DOM Level 3
 * @version $Revision: 511423 $, $Date: 2007-02-24 22:21:05 -0500 (Sat, 24 Feb 2007) $
 */
public interface UserDataHandler {

    // An integer indicating the type of operation being performed on a node.

    /**
     * The node is cloned, using Node.cloneNode().
     */
    public static final short NODE_CLONED = 1;

    /**
     * The node is imported, using Document.importNode().
     */
    public static final short NODE_IMPORTED = 2;

    /**
     * The node is deleted.
     */
    public static final short NODE_DELETED = 3;

    /**
     * The node is renamed, using Document.renameNode().
     */
    public static final short NODE_RENAMED = 4;

    /**
     * The node is adopted, using Document.adoptNode().
     */
    public static final short NODE_ADOPTED = 5;

    /**
     * This method is called whenever the node for which this handler is
     * registered is imported or cloned.<br/>
     * DOM applications must not raise exceptions in a UserDataHandler. The
     * effect of throwing exceptions from the handler is DOM implementation
     * dependent.
     * @param operation Specifies the type of operation that is being
     * performed on the node.
     * @param key Specifies the key for which this handler is being called.
     * @param data Specifies the data for which this handler is being called.
     * @param src Specifies the node being cloned, adopted, imported, or
     * renamed. This is null when the node is being deleted.
     * @param dst Specifies the node newly created if any, or null.
     */
    public void handle(short operation, String key, Object data, Node src, Node dst);
}