/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Stopwatch.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice;

/**
 * Stopwatch is a debugging tool for manually profiling code execution.
 * This class will probably be removed for a production release.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public final class Stopwatch {
    String label = null;
    long total = 0;
    long begin = 0;
    long end = 0;

    public Stopwatch() {
    }

    public Stopwatch(boolean immediate) {
        if (immediate) {
            start();
        }
    }

    public Stopwatch(String label) {
        this.label = label;
    }

    public Stopwatch(String label, boolean immediate) {
        this.label = label;
        if (immediate) {
            start();
        }
    }

    public void start() {
        begin = System.currentTimeMillis();
    }

    public long stop() {
        end = System.currentTimeMillis();
        total += (end - begin);
        return total;
    }

    public void cancel() {
        begin = 0;
        end = 0;
    }

    public void reset() {
        total = 0;
        begin = 0;
        end = 0;
    }

    public long elapsed() {
        if (end != 0) {
            return (end - begin);
        } else {
            return System.currentTimeMillis() - begin;
        }
    }

    public long total() {
        if (end != 0) {
            return total;
        } else {
            return (System.currentTimeMillis() - begin) + total;
        }
    }

    public String toString() {
        long t = total();

        StringBuffer sb = new StringBuffer();
        if (label != null) {
            sb.append(label + ": ");
        }

        long hour = t / 3600000;
        if (hour > 0) {
            sb.append(hour + "h ");
            t = t % 3600000;
        }

        long min = t / 60000;
        if (min > 0) {
            sb.append(min + "m ");
            t = t % 60000;
        }

        long sec = t / 1000;
        if (sec > 0) {
            sb.append(sec + "s ");
            t = t % 1000;
        }

        if (t > 0) {
            sb.append(t + "ms");
        }

        return sb.toString();
    }
}

