/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ResourceIteratorImpl.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.client.xmldb;

import org.xmldb.api.base.ErrorCodes;
import org.xmldb.api.base.Resource;
import org.xmldb.api.base.ResourceIterator;
import org.xmldb.api.base.XMLDBException;

import java.util.Iterator;
import java.util.List;

/**
 * An iterator over a collection of resources.
 *
 * @author  <a href="mailto:vladimir@apache.org">Vladimir R. Bossicard</a>
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class ResourceIteratorImpl implements ResourceIterator {

    private Iterator iterator = null;

    public ResourceIteratorImpl(List resources) {
        if (resources != null) {
            this.iterator = resources.iterator();
        }
    }

    public boolean hasMoreResources()
            throws XMLDBException {
        if (this.iterator != null) {
            return this.iterator.hasNext();
        } else {
            return false;
        }
    }

    public Resource nextResource()
            throws XMLDBException {
        if (this.iterator != null) {
            if (this.iterator.hasNext()) {
                return (Resource) iterator.next();
            }
        }
        throw new XMLDBException(ErrorCodes.NO_SUCH_RESOURCE);
    }

}
