/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Xindice.java 600165 2007-12-01 16:50:29Z vgritsenko $
 */

package org.apache.xindice.server;

/**
 * Defines the Xindice version-related constants.
 *
 * @version $Revision: 600165 $, $Date: 2007-12-01 11:50:29 -0500 (Sat, 01 Dec 2007) $
 */
public interface Xindice {

    /**
     * System property specyfying location of the Xindice installation.
     * Used by the tools to locate configuration files and libraries.
     */
    public static final String PROP_XINDICE_HOME = "xindice.home";

    /**
     * System property specyfying location of the Xindice database.
     * If present, this property overrides location preferred by the driver.
     */
    public static final String PROP_XINDICE_DB_HOME = "xindice.db.home";

    /**
     * System property specyfying location of the Xindice database configuration
     * file (system.xml).
     */
    public static final String PROP_XINDICE_CONFIGURATION = "xindice.configuration";

    // Version Information
    public static final int MajorVersion = 1;
    public static final int MinorVersion = 1;
    public static final int SubMinorVersion = 0;
    public static final String Version = "1.2m1";
    public static final String Codename = "SpringBreak";

    // Copyright/Authorship Information
    public static final String Title   = "Xindice";
    public static final String Author  = "The Apache Software Foundation";
    public static final String Year    = "2007";
    public static final String Company = "The Apache Software Foundation";
    public static final String URL     = "http://xml.apache.org/xindice/";

    // Default configuration if a system.xml file isn't available.
    public static final String DEFAULT_CONFIGURATION
            = "<xindice>"
            + "    <root-collection dbroot='./db/' name='db'>"
            + "        <queryengine>"
            + "            <resolver autoindex='false' class='org.apache.xindice.core.query.XPathQueryResolver'/>"
            + "            <resolver class='org.apache.xindice.core.xupdate.XUpdateQueryResolver'/>"
            + "            <resolver class='org.apache.xindice.core.query.TextQueryResolver'/>"
            + "        </queryengine>"
            + "    </root-collection>"
            + "    <xml-rpc>"
            + "        <driver name='xerces'/>"
            + "    </xml-rpc>"
            + "</xindice>";
}
