/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: GetCollectionConfiguration.java 595817 2007-11-16 20:49:03Z vgritsenko $
 */

package org.apache.xindice.server.rpc.messages;

import org.apache.xindice.server.rpc.RPCDefaultMessage;

import org.xmldb.api.base.ErrorCodes;
import org.xmldb.api.base.XMLDBException;

import java.util.HashMap;
import java.util.Map;

/**
 *
 * @version $Revision: 595817 $, $Date: 2007-11-16 15:49:03 -0500 (Fri, 16 Nov 2007) $
 */
public class GetCollectionConfiguration extends RPCDefaultMessage {

    public Map execute(Map message) throws Exception {

        if (!message.containsKey(COLLECTION)) {
            throw new Exception(MISSING_COLLECTION_PARAM);
        }

        Map result = new HashMap(3);
        try {
            /* getCollection() throws an exception if collection doesnt exist */
            getCollection((String) message.get(COLLECTION));
            result.put(RESULT, "yes");
        } catch (XMLDBException e) {
            if (e.errorCode == ErrorCodes.NO_SUCH_DATABASE) {
                throw e;
            }
            result.put(RESULT, "no");
        } catch (Exception e) {
            result.put(RESULT, "no");
        }

        return result;
    }
}
