/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Configurable.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.util;

/**
 * Configurable is a simple interface used to pass configuration information
 * to an object.  The implementing object is ultimately responsible for
 * maintaining any of that configuration information in any fashion it so
 * desires.  Most will create a Configuration instance to manage the data
 * in a consistent, and easy to access fashion.
 * <br><br>
 * A Configurable object should be considered 'configured' after receiving
 * a call to setConfig().  No additional configuration activities should be
 * expected of the instance, and so setConfig() should be the last call in
 * any set of configuration commands against an object.
 *
 * @see org.apache.xindice.util.Configuration
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface Configurable {

    /**
     * setConfig sets the configuration information for the Configurable
     * object instance.
     *
     * @param config The configuration Node
     */
    void setConfig(Configuration config) throws XindiceException;

    /**
     * getConfig retrieves the configuration information for the
     * Configurable object instance.
     *
     * @return The configuration Node
     */
    Configuration getConfig();
}
