/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Options.java 551438 2007-06-28 04:09:44Z vgritsenko $
 */

package org.apache.xindice.webadmin.webdav.components;

import org.apache.xindice.webadmin.Location;
import org.apache.xindice.webadmin.webdav.DAVRequest;
import org.apache.xindice.webadmin.webdav.DAVResponse;

import javax.servlet.ServletException;

import java.io.IOException;

/**
 * This class implements the Options command for WebDAV operations on
 * Xindice.
 *
 * @author <a href="mailto:jmetzner@apache.org">Jan Metzner</a>
 * @author <a href="mailto:gianugo@apache.org">Gianugo Rabellino</a>
 * @version $Revision: 551438 $, $Date: 2007-06-28 00:09:44 -0400 (Thu, 28 Jun 2007) $
 */
public class Options implements DAVComponent {

    public void execute(DAVRequest req, DAVResponse res, Location target) throws ServletException, IOException {
        // DAV Level 1
        res.addHeader("DAV", "1");

        String methodsAllowed;
        if (target.isRoot()) {
            methodsAllowed = "OPTIONS, PROPFIND";
        } else if (target.getName() == null) {
            methodsAllowed = "OPTIONS, POST, DELETE, PROPFIND, PROPPATCH, COPY, MOVE, PUT, MKCOL";
        } else {
            methodsAllowed = "OPTIONS, GET, HEAD, POST, DELETE, PROPFIND, PROPPATCH, COPY, MOVE";
        }

        res.addHeader("Allow", methodsAllowed);

        // MS support
        res.addHeader("MS-Author-Via", "DAV");
    }
}
