/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.xindice.webadmin.webdav.components.props;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.Entry;
import org.apache.xindice.webadmin.PartialResponse;

/**
 * DAVProperty represents resources' properties. Property value may vary
 * depending on resource type and value, and may be available for all the
 * resources or only for specific types of resources.
 *
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public interface DAVProperty {
    /**
     * Returns property name
     * @return property name
     */
    public String getName();

    /**
     * Builds a property content tree for the root node ("/").
     * @return Property content tree or null, if property is not applicable.
     */
    public PartialResponse.Content getRootProperty();

    /**
     * Builds a property content tree for collection.
     * @param col Collection
     * @return Property content tree or null, if property is not applicable.
     */
    public PartialResponse.Content getProperty(Collection col);

    /**
     * Builds a property content tree for collection entry.
     * @param entry Collection entry
     * @return Property content tree or null, if property is not applicable.
     */
    public PartialResponse.Content getProperty(Entry entry);
}
