/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Signatures.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.xml;

/**
 * Signatures defines identifying values for the types that the Xindice DOM
 * recognizes.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface Signatures {

    /*
     * Signature byte consists of following fields:
     *   Node type          0xC0
     *   Text node type     0x20 (in text node)
     *   Element bits       0x30 (in elem node)
     *   Declaration type   0x3C (in decl node)
     */

    byte NODE_TEXT =        0x00;
    byte NODE_ELEM =        0x40;
    byte NODE_PROC = (byte) 0x80;
    byte NODE_DECL = (byte) 0xC0;

    byte TEXT_TEXT     = 0x00;
    byte TEXT_ENTITY   = 0x20;

    byte ELEM_ATTRS    = 0x20;
    byte ELEM_CHILDREN = 0x10;

    byte DECL_ELEMENT  = 0x04;
    byte DECL_ATTLIST  = 0x08;
    byte DECL_CDATA    = 0x10;
    byte DECL_REPLACED = 0x14;
    byte DECL_ENTITY   = 0x18;
    byte DECL_COMMENT  = 0x20;
    byte DECL_DOCTYPE  = 0x28;
    byte DECL_NOTATION = 0x30;
    byte DECL_IGNORE   = 0x38;
    byte DECL_INCLUDE  = 0x3C;

    byte SIZE_NONE     = 0x00;
    byte SIZE_INT      = 0x01;
    byte SIZE_SHORT    = 0x02;
    byte SIZE_BYTE     = 0x03;

    int ENT_DEFINED   = 0x01; // Symbol_ID attached
    int ENT_AMP       = 0x02; // &amp;
    int ENT_LT        = 0x03; // &lt;
    int ENT_GT        = 0x04; // &gt;
    int ENT_QUOT      = 0x05; // &quot;
    int ENT_APOS      = 0x06; // &apos;
    int ENT_UNICODE   = 0x1F; // &#x...;

    int Unknown = -1;
}
