/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: SymbolTableSymbols.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.xml;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.xindice.xml.dom.DOMParser;

import org.w3c.dom.Element;

/**
 * SymbolTableSymbols is class that represents the hard-coded definition
 * of a compressed symbol table.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public final class SymbolTableSymbols extends SymbolTable {

    private static final Log log = LogFactory.getLog(SymbolTableSymbols.class);

    private static String SYMBOLS_DEFINITION
            = "<symbols>"
            + "  <symbol name='" + SYMBOLS + "' id='0'/>"
            + "  <symbol name='" + SYMBOL  + "' id='1'/>"
            + "  <symbol name='" + NAME    + "' id='2'/>"
            + "  <symbol name='" + ID      + "' id='3'/>"
            + "  <symbol name='" + NSURI   + "' id='4'/>"
            + "</symbols>";

    private static SymbolTableSymbols SYMBOLS_INSTANCE;


    private SymbolTableSymbols() {
        try {
            Element symbols = DOMParser.toDocument(SYMBOLS_DEFINITION).getDocumentElement();
            streamFromXML(symbols);
        } catch (Exception e) {
            // Should never happen
            log.fatal("Failed to create SymbolTableSymbols", e);
        }
    }

    public static String getDefinition() {
        return SYMBOLS_DEFINITION;
    }

    public static SymbolTableSymbols getInstance() {
        if (SYMBOLS_INSTANCE == null) {
            SYMBOLS_INSTANCE = new SymbolTableSymbols();
        }

        return SYMBOLS_INSTANCE;
    }
}
