/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DatabaseImplTest.java 511423 2007-02-25 03:21:05Z vgritsenko $
 */

package org.apache.xindice.client.xmldb;

import junit.framework.TestCase;

/**
 * @version $Revision: 511423 $, $Date: 2007-02-24 22:21:05 -0500 (Sat, 24 Feb 2007) $
 * @author Vladimir R. Bossicard <vladimir@apache.org>
 */
public class DatabaseImplTest extends TestCase {

   private DatabaseImpl db;

   public void setUp() throws Exception {
      db = new DatabaseImpl();
   }

   public void testGetName() throws Exception {
      assertEquals("xindice, xindice-embed, xindice-managed", db.getName());
   }

   public void testAcceptXmlRpcURI() throws Exception {
      assertTrue(db.acceptsURI("xindice://"));

      assertTrue(db.acceptsURI("xindice://"));
      assertFalse(db.acceptsURI("xindice-embed://"));
      assertFalse(db.acceptsURI("xindice-corba://"));
      assertFalse(db.acceptsURI(""));
      assertFalse(db.acceptsURI(null));
   }

   public void testAcceptEmbedURI() throws Exception {
      assertTrue(db.acceptsURI("xindice-embed://"));

      assertFalse(db.acceptsURI("xindice://"));
      assertTrue(db.acceptsURI("xindice-embed://"));
      assertFalse(db.acceptsURI("xindice-corba://"));
      assertFalse(db.acceptsURI(""));
      assertFalse(db.acceptsURI(null));
   }

   public void testFailAcceptCorbaURI() throws Exception {
      assertFalse(db.acceptsURI("xindice-corba://"));

      assertFalse(db.acceptsURI("xindice-corba://"));
      assertFalse(db.acceptsURI(""));
      assertFalse(db.acceptsURI(null));
   }

   public void testFailAcceptNullURI() throws Exception {
      assertFalse(db.acceptsURI(null));

      assertFalse(db.acceptsURI("xindice-corba://"));
      assertFalse(db.acceptsURI(""));
      assertFalse(db.acceptsURI(null));
   }

   public void testFailAcceptEmptyURI() throws Exception {
      assertFalse(db.acceptsURI(""));

      assertFalse(db.acceptsURI("xindice-corba://"));
      assertFalse(db.acceptsURI(""));
      assertFalse(db.acceptsURI(null));
   }
}
